"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils = require("tns-core-modules/utils/utils");
var DocumentPickerDelegateImpl = (function (_super) {
    __extends(DocumentPickerDelegateImpl, _super);
    function DocumentPickerDelegateImpl() {
        return _super.call(this) || this;
    }
    DocumentPickerDelegateImpl.prototype.cleanup = function (controller) {
        this._resolve = null;
        this._reject = null;
        controller.delegate = null;
    };
    DocumentPickerDelegateImpl.prototype.documentPickerDidPickDocumentAtURL = function (controller, url) {
        this._resolve({
            files: [url.absoluteString],
            ios: url
        });
        this.cleanup(controller);
    };
    DocumentPickerDelegateImpl.prototype.documentPickerDidPickDocumentsAtURLs = function (controller, urls) {
        var output = [];
        for (var i = 0; i < urls.count; i++) {
            output.push(urls[i].absoluteString);
        }
        this._resolve({
            files: output,
            ios: urls
        });
        this.cleanup(controller);
    };
    DocumentPickerDelegateImpl.prototype.documentPickerWasCancelled = function (controller) {
        this._reject('cancelled');
        this.cleanup(controller);
    };
    DocumentPickerDelegateImpl.ObjCProtocols = [UIDocumentPickerDelegate];
    DocumentPickerDelegateImpl.initWithResolveReject = function (resolve, reject) {
        var delegate = DocumentPickerDelegateImpl.new();
        delegate._resolve = resolve;
        delegate._reject = reject;
        return delegate;
    };
    return DocumentPickerDelegateImpl;
}(NSObject));
exports.openFilePicker = function (params) {
    var documentTypes;
    if (!params) {
        params = {};
    }
    if (!params.extensions) {
        params.extensions = ['public.data'];
    }
    if (params.extensions && params.extensions.length > 0) {
        documentTypes = utils.ios.collections.jsArrayToNSArray(params.extensions);
    }
    return new Promise(function (resolve, reject) {
        var delegate = DocumentPickerDelegateImpl.initWithResolveReject(resolve, reject);
        var controller = UIDocumentPickerViewController.alloc().initWithDocumentTypesInMode(documentTypes, params.pickerMode !== undefined ? params.pickerMode : 0);
        controller.allowsMultipleSelection = !!params.multipleSelection;
        if (delegate) {
            controller.delegate = delegate;
            var app = UIApplication.sharedApplication;
            var window_1 = app.keyWindow || (app.windows.count > 0 && app.windows[0]);
            var visibleVC = utils.ios.getVisibleViewController(window_1.rootViewController);
            visibleVC.presentViewControllerAnimatedCompletion(controller, true, null);
        }
    });
};
//# sourceMappingURL=simple-filepicker.ios.js.map